@@ -1,3 +1,4 @@
+"""Module provider for DNS Simple"""
 from __future__ import absolute_import
 import json
 import logging
@@ -11,7 +12,8 @@ LOGGER = logging.getLogger(__name__)
 NAMESERVER_DOMAINS = ['dnsimple.com']
 
 
-def ProviderParser(subparser):
+def provider_parser(subparser):
+    """Configure provider parser for DNS Simple"""
     subparser.add_argument(
         "--auth-token", help="specify api token for authentication")
     subparser.add_argument(
@@ -19,11 +21,12 @@ def ProviderParser(subparser):
     subparser.add_argument(
         "--auth-password", help="specify password for authentication")
     subparser.add_argument(
-        "--auth-2fa", help="specify two-factor auth token (OTP) to use with email/password authentication")
+        "--auth-2fa",
+        help="specify two-factor auth token (OTP) to use with email/password authentication")
 
 
 class Provider(BaseProvider):
-
+    """Provider class for DNS Simple"""
     def __init__(self, config):
         super(Provider, self).__init__(config)
         self.domain_id = None
@@ -31,7 +34,7 @@ class Provider(BaseProvider):
         self.api_endpoint = self._get_provider_option(
             'api_endpoint') or 'https://api.dnsimple.com/v2'
 
-    def authenticate(self):
+    def _authenticate(self):
 
         payload = self._get('/accounts')
 
@@ -41,7 +44,7 @@ class Provider(BaseProvider):
         for account in payload:
             dompayload = self._get(
                 '/{0}/domains'.format(account['id']), query_params={'name_like': self.domain})
-            if len(dompayload) > 0 and dompayload[0]['id']:
+            if dompayload and dompayload[0]['id']:
                 self.account_id = account['id']
                 self.domain_id = dompayload[0]['id']
 
@@ -50,14 +53,14 @@ class Provider(BaseProvider):
 
     # Create record. If record already exists with the same content, do nothing
 
-    def create_record(self, type, name, content):
+    def _create_record(self, rtype, name, content):
         # check if record already exists
-        existing_records = self.list_records(type, name, content)
+        existing_records = self._list_records(rtype, name, content)
         if len(existing_records) == 1:
             return True
 
         record = {
-            'type': type,
+            'type': rtype,
             'name': self._relative_name(name),
             'content': content
         }
@@ -77,24 +80,27 @@ class Provider(BaseProvider):
     # List all records. Return an empty list if no records found
     # type, name and content are used to filter records.
     # If possible filter during the query, otherwise filter after response is received.
-    def list_records(self, type=None, name=None, content=None):
-        filter = {}
-        if type:
-            filter['type'] = type
+    def _list_records(self, rtype=None, name=None, content=None):
+        filter_query = {}
+        if rtype:
+            filter_query['type'] = rtype
         if name:
-            filter['name'] = self._relative_name(name)
+            filter_query['name'] = self._relative_name(name)
         payload = self._get(
-            '/{0}/zones/{1}/records'.format(self.account_id, self.domain), query_params=filter)
+            '/{0}/zones/{1}/records'.format(self.account_id, self.domain),
+            query_params=filter_query)
 
         records = []
         for record in payload:
             processed_record = {
                 'type': record['type'],
-                'name': '{}'.format(self.domain) if record['name'] == "" else '{0}.{1}'.format(record['name'], self.domain),
+                'name': '{}'.format(
+                    self.domain) if record['name'] == "" else '{0}.{1}'.format(
+                        record['name'],
+                        self.domain),
                 'ttl': record['ttl'],
                 'content': record['content'],
-                'id': record['id']
-            }
+                'id': record['id']}
             if record['priority']:
                 processed_record['priority'] = record['priority']
             records.append(processed_record)
@@ -107,12 +113,12 @@ class Provider(BaseProvider):
         return records
 
     # Create or update a record.
-    def update_record(self, identifier, type=None, name=None, content=None):
+    def _update_record(self, identifier, rtype=None, name=None, content=None):
 
         data = {}
 
         if identifier is None:
-            records = self.list_records(type, name, content)
+            records = self._list_records(rtype, name, content)
             identifiers = [record["id"] for record in records]
         else:
             identifiers = [identifier]
@@ -128,20 +134,20 @@ class Provider(BaseProvider):
         if self._get_provider_option('regions'):
             data['regions'] = self._get_provider_option('regions')
 
-        for identifier in identifiers:
-            payload = self._patch(
-                '/{0}/zones/{1}/records/{2}'.format(self.account_id, self.domain, identifier), data)
-            LOGGER.debug('update_record: %s', identifier)
+        for one_identifier in identifiers:
+            self._patch('/{0}/zones/{1}/records/{2}'
+                        .format(self.account_id, self.domain, one_identifier), data)
+            LOGGER.debug('update_record: %s', one_identifier)
 
         LOGGER.debug('update_record: %s', True)
         return True
 
     # Delete an existing record.
     # If record does not exist, do nothing.
-    def delete_record(self, identifier=None, type=None, name=None, content=None):
+    def _delete_record(self, identifier=None, rtype=None, name=None, content=None):
         delete_record_id = []
         if not identifier:
-            records = self.list_records(type, name, content)
+            records = self._list_records(rtype, name, content)
             delete_record_id = [record['id'] for record in records]
         else:
             delete_record_id.append(identifier)
@@ -149,7 +155,7 @@ class Provider(BaseProvider):
         LOGGER.debug('delete_records: %s', delete_record_id)
 
         for record_id in delete_record_id:
-            payload = self._delete(
+            self._delete(
                 '/{0}/zones/{1}/records/{2}'.format(self.account_id, self.domain, record_id))
 
         # is always True at this point; if a non 2xx response is returned, an error is raised.
@@ -158,7 +164,7 @@ class Provider(BaseProvider):
 
     # Helpers
 
-    def _request(self, action='GET',  url='/', data=None, query_params=None):
+    def _request(self, action='GET', url='/', data=None, query_params=None):
         if data is None:
             data = {}
         if query_params is None:
@@ -172,7 +178,8 @@ class Provider(BaseProvider):
         if self._get_provider_option('auth_token'):
             default_headers['Authorization'] = "Bearer {0}".format(
                 self._get_provider_option('auth_token'))
-        elif self._get_provider_option('auth_username') and self._get_provider_option('auth_password'):
+        elif (self._get_provider_option('auth_username')
+              and self._get_provider_option('auth_password')):
             default_auth = (self._get_provider_option(
                 'auth_username'), self._get_provider_option('auth_password'))
             if self._get_provider_option('auth_2fa'):
@@ -181,16 +188,16 @@ class Provider(BaseProvider):
         else:
             raise Exception('No valid authentication mechanism found')
 
-        r = requests.request(action, self.api_endpoint + url, params=query_params,
-                             data=json.dumps(data),
-                             headers=default_headers,
-                             auth=default_auth)
+        response = requests.request(action, self.api_endpoint + url, params=query_params,
+                                    data=json.dumps(data),
+                                    headers=default_headers,
+                                    auth=default_auth)
         # if the request fails for any reason, throw an error.
-        r.raise_for_status()
-        if r.text and r.json()['data'] is None:
+        response.raise_for_status()
+        if response.text and response.json()['data'] is None:
             raise Exception('No data returned')
 
-        return r.json()['data'] if r.text else None
+        return response.json()['data'] if response.text else None
 
     def _patch(self, url='/', data=None, query_params=None):
         return self._request('PATCH', url, data=data, query_params=query_params)
